==> verum-dezyne-2.16.0-x86_64-windows.zip: dezyne-2.16.0/gnu/share/guile/site/3.0/ide/config.scm <==
;;; Verum-Dezyne --- An IDE for Dezyne
;;;
;;; Copyright © 2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
;;;
;;; This file is part of Verum-Dezyne.
;;;
;;; Verum-Dezyne is property of Verum Software Tools BV <support@verum.com>.
;;; All rights reserved.

(define-module (ide config)
  #:export (%datadir
            %datarootdir
            %daemon-config-file
            %default-editor-port
            %default-http-port
            %default-ide-port
            %default-view-port
            %editor-port
            %http-port
            %ide-port
            %imports
            %pkgdatadir
            %prefix
            %user-cache-dir
            %user-config-dir
            %user-runtime-dir
            %version
            %view-port
            %web-root))

(define %imports
  '())

(define %prefix
  (or (and (getenv "IDE_UNINSTALLED") (getenv "IDE_PREFIX"))
      "/gnu/store/nr13nc769qig1wmp4nkjxmsbf3xip7qz-verum-dezyne-mingw-2.16.0"))

(define %datadir
  (or (and (getenv "IDE_UNINSTALLED") %prefix)
      "/gnu/store/nr13nc769qig1wmp4nkjxmsbf3xip7qz-verum-dezyne-mingw-2.16.0/share"))

(define %datarootdir
  (or (and (getenv "IDE_UNINSTALLED") %prefix)
      "/gnu/store/nr13nc769qig1wmp4nkjxmsbf3xip7qz-verum-dezyne-mingw-2.16.0/share"))

(define %pkgdatadir
  (or (and (getenv "IDE_UNINSTALLED") %prefix)
      (getenv "IDE_DATADIR")
      "/gnu/store/nr13nc769qig1wmp4nkjxmsbf3xip7qz-verum-dezyne-mingw-2.16.0/share/verum-dezyne"))

(define %user-cache-dir
  (string-append (or (getenv "XDG_CACHE_HOME")
                     (string-append (getenv "HOME") "/.cache"))
                 "/dzn"))

(define %user-config-dir
  (string-append (or (getenv "XDG_CONFIG_HOME")
                     (string-append (getenv "HOME") "/.config"))
                 "/dzn"))

(define %user-runtime-dir
  (string-append (or (getenv "XDG_RUNTIME_DIR")
                     (and (defined? 'getuid)
                          (let ((dir (format #f "/run/user/~s" (getuid))))
                            (and (file-exists? dir)
                                 dir)))
                     (getenv "XDG_CACHE_HOME")
                     (string-append (getenv "HOME") "/.cache"))
                 "/dzn"))

(define %daemon-config-file
  (string-append %user-config-dir "/daemon.scm"))

(define %web-root
  (string-append %pkgdatadir "/dzn"))

(define %version
  "2.16.0")

(define %default-editor-port
  3003)

(define %default-http-port
  3000)

(define %default-ide-port
  3001)

(define %default-view-port
  3002)

(define %editor-port
  3003)

(define %http-port
  3000)

(define %ide-port
  3001)

(define %view-port
  3002)

==> verum-dezyne-2.16.1-x86_64-windows.zip: dezyne-2.16.1/gnu/share/guile/site/3.0/ide/config.scm <==
;;; Verum-Dezyne --- An IDE for Dezyne
;;;
;;; Copyright © 2020 Jan (janneke) Nieuwenhuizen <janneke@gnu.org>
;;;
;;; This file is part of Verum-Dezyne.
;;;
;;; Verum-Dezyne is property of Verum Software Tools BV <support@verum.com>.
;;; All rights reserved.

(define-module (ide config)
  #:export (%datadir
            %datarootdir
            %daemon-config-file
            %default-editor-port
            %default-http-port
            %default-ide-port
            %default-view-port
            %editor-port
            %http-port
            %ide-port
            %imports
            %pkgdatadir
            %prefix
            %user-cache-dir
            %user-config-dir
            %user-runtime-dir
            %version
            %view-port
            %web-root))

(define %imports
  '())

(define %prefix
  (or (and (getenv "IDE_UNINSTALLED") (getenv "IDE_PREFIX"))
      "/gnu/store/akbizlkm24l4nb64zy6slnym5irrqm62-verum-dezyne-mingw-2.16.1"))

(define %datadir
  (or (and (getenv "IDE_UNINSTALLED") %prefix)
      "/gnu/store/akbizlkm24l4nb64zy6slnym5irrqm62-verum-dezyne-mingw-2.16.1/share"))

(define %datarootdir
  (or (and (getenv "IDE_UNINSTALLED") %prefix)
      "/gnu/store/akbizlkm24l4nb64zy6slnym5irrqm62-verum-dezyne-mingw-2.16.1/share"))

(define %pkgdatadir
  (or (and (getenv "IDE_UNINSTALLED") %prefix)
      (getenv "IDE_DATADIR")
      "/gnu/store/akbizlkm24l4nb64zy6slnym5irrqm62-verum-dezyne-mingw-2.16.1/share/verum-dezyne"))

(define %user-cache-dir
  (string-append (or (getenv "XDG_CACHE_HOME")
                     (string-append (getenv "HOME") "/.cache"))
                 "/dzn"))

(define %user-config-dir
  (string-append (or (getenv "XDG_CONFIG_HOME")
                     (string-append (getenv "HOME") "/.config"))
                 "/dzn"))

(define %user-runtime-dir
  (string-append (or (getenv "XDG_RUNTIME_DIR")
                     (and (defined? 'getuid)
                          (let ((dir (format #f "/run/user/~s" (getuid))))
                            (and (file-exists? dir)
                                 dir)))
                     (getenv "XDG_CACHE_HOME")
                     (string-append (getenv "HOME") "/.cache"))
                 "/dzn"))

(define %daemon-config-file
  (string-append %user-config-dir "/daemon.scm"))

(define %web-root
  (string-append %pkgdatadir "/dzn"))

(define %version
  "2.16.1")

(define %default-editor-port
  3003)

(define %default-http-port
  3000)

(define %default-ide-port
  3001)

(define %default-view-port
  3002)

(define %editor-port
  3003)

(define %http-port
  3000)

(define %ide-port
  3001)

(define %view-port
  3002)
